/**
 * @file Main.c
 * @author Ryan Lipski, Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/11/2015\n Created: 11/11/2014 11:57:32 AM
 * @brief This file is code main for testing and the main program.
 */

#include "Main_Program.h"
#include "Master_Build_Control.h"
#include "Testing/Test_Battery.h"
#include "Testing/Test_H_Bridge.h"
#include "Testing/Test_I2C_Compass.h"
#include "Testing/Test_LED.h"
#include "Testing/Test_Motor_Control.h"
#include "Testing/Test_Multiplexer.h"
#include "Testing/Test_Photodiodes.h"
#include "Testing/Test_Pressure_Sensor.h"
#include "Testing/Test_Swarming.h"

/**
 * @brief This the main for the entire project use Main_Mode to select the portion of the code to test.
 */
int main(void)
{
    /* Main for the entire project. */
    #if Main_Mode == 1
        Main_Program();
    /* Test the swarming code. */
    #elif Main_Mode == 2
        Test_Swarming();
    /* Test the LSM303 (I2C Compass/Accelerometer). */
    #elif Main_Mode == 3
        Test_I2C_Compass();
    /* Test the DRV8830 (I2C H-Bridge). */
    #elif Main_Mode == 4
        Test_H_Bridge();
    /* Test the LED toggling. */
    #elif Main_Mode == 5
        Test_LED();
    /* Test the Multiplexer and the ADC. */
    #elif Main_Mode == 6
        Test_Multiplexer();
    /* Test the photodiode circuits. */
    #elif Main_Mode == 7
        Test_Photodiodes();
    /* Test the pressure sensor. */
    #elif Main_Mode == 8
        Test_Pressure_Sensor();
    /* Test the battery reading code. */
    #elif Main_Mode == 9
        Test_Battery();
    /* Test the motor control. */
    #elif Main_Mode == 10
        Test_Motor_Control();
    /* Test the swarming code. */
    #elif Main_Mode == 11
        Test_Swarming();
    #endif
    /* Return of 0 for main. */
    return(0);
}