/**
 * @file Master_Build_Control.h
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 3/20/2015\n Created: 2/26/2015 4:23:20 PM
 * @brief This is the header file to control which program builds.
 */

#ifndef MASTER_BUILD_CONTROL_H_
#define MASTER_BUILD_CONTROL_H_

/**
 * @brief Different modes for the main function\n
 * Mode 1: Main for the entire project.\n
 * Mode 2: Test the swarming code.\n
 * Mode 3: Test the LSM303 (I2C Compass/Accelerometer).\n
 * Mode 4: Test the DRV8830 (I2C H-Bridge).\n
 * Mode 5: Test the LED toggling.\n
 * Mode 6: Test the Multiplexer and the ADC.\n
 * Mode 7: Test the photodiode circuits.\n
 * Mode 8: Test the pressure sensor.\n
 * Mode 9: Test the battery reading code.\n
 * Mode 10: Test the motor control.\n
 * Mode 11: Test the swarming code.\n
 */
#define Main_Mode 1
/**
 * @brief Different modes for the compass function\n
 * Compass Test Mode 0: Test Acceleration and Magnetometer Readings\n
 * Compass Test Mode 1: Test Heading\n
 */ 
#define Compass_Test_Mode 0
/**
 * @brief Different modes for the h-bridge test function\n
 * H-Bridge Test Mode 0: Test X-axis\n
 * H-Bridge Test Mode 1: Test Y-axis\n
 * H-Bridge Test Mode 2: Test Z-axis\n
 */ 
#define H_Bridge_Test_Mode 0
/**
 * @brief Different modes for the h-bridge test function\n
 * H-Bridge Test Direction 0: Test goes from zero to max then repeats\n
 * H-Bridge Test Direction 1: Test goes from max to zero then repeats\n
 */
#define H_Bridge_Test_Direction 0
/**
 * @brief Different modes for the LED function\n
 * LED Test Mode 0: Test the toggling of the front LED\n
 * LED Test Mode 1: Test changing between 3 LEDs\n
 */ 
#define LED_Test_Mode 0
/**
 * @brief Different modes for the multiplexer function\n
 * Multiplexer Test Mode 0: Test a single pin\n
 * Multiplexer Test Mode 1: Test all of the pins\n
 * Multiplexer Test Mode 2: Test a single voltage conversion\n
 * Multiplexer Test Mode 3: Test voltage conversion on all of the pins\n
 */ 
#define Multiplexer_Test_Mode 0
/**
 * @brief Different modes for the photodiode function\n
 * Photodiode Test Mode 0: Test front diode\n
 * Photodiode Test Mode 1: Test left side diodes\n
 * Photodiode Test Mode 2: Test right side diodes\n
 * Photodiode Test Mode 3: Test rear diode\n
 * Photodiode Test Mode 4: Test all diodes\n
 * Photodiode Test Mode 5: Test all diodes and change the LEDs\n
 */ 
#define Photodiode_Test_Mode 0
/**
 * @brief Different modes for the motor control test function.\n
 * Motor Control Test Mode 0: Varying Test Forward/Reverse\n
 * Motor Control Test Mode 1: Varying Test Left/Right\n
 * Motor Control Test Mode 2: Varying Test Up/Down\n
 * Motor Control Test Mode 0: Constant Test Forward/Reverse\n
 * Motor Control Test Mode 1: Constant Test Left/Right\n
 * Motor Control Test Mode 2: Constant Test Up/Down\n
 */ 
#define Motor_Control_Test_Mode 0
/**
 * @brief Prints the different regions for the swarming code. 1: On / 0: Off
 */
#define Print_Region 0
/**
 * @brief Prints the information for motor control code. 1: On / 0: Off
 */
#define Print_Motor_Information 0
/**
 * @brief Prints the different state information for the state machine code. 1: On / 0: Off
 */
#define Print_State 0
/**
 * @brief Prints the different information for the h bridge update code. 1 for on 0 for off.
 */
#define H_Bridge_Print 0
/**
 * @brief Selects which state to test after the initialization. Note that this has to be > 0.
 */
#define State_Machine_Test_Mode 0
#endif /* MASTER_BUILD_CONTROL_H_ */