/**
 * @file Interrupt.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 1/29/2015\n Created: 1/27/2015 4:38:39 PM
 * @brief This file is code for the interrupts on the ATMega328P.
 */ 

#include <avr/interrupt.h>
#include "../../Algorithms/Motor_Control/Motor_Control.h"
#include "../../Algorithms/Navigation/Swarming.h"
#include "../../Algorithms/State_Machine/State_Machine.h"
#include "../../Microcontroller/Interrupt/Interrupt.h"

/**
 * @brief Interrupt for timer 0 compare A vector, which is used to update the motor control value.
 */ 
ISR(TIMER0_COMPA_vect)
{
    /* Enable the flag to update the motor control values. */
    Motor_Control_Enable_Flag();
}

/**
 * @brief Interrupt for timer 1 compare A vector, which is used to update the swarming value.
 */ 
ISR(TIMER1_COMPA_vect)
{
    /* Enable the flag to update the swarming values. */
    Swarming_Enable_Flag();
}

/**
 * @brief Interrupt for timer 2 compare A vector, which is used to update the state machine.
 */ 
ISR(TIMER2_COMPA_vect)
{
    /* Enable the flag to update the state machine. */
    State_Machine_Enable_Flag();
}