/**
 * @file Timer.c
 * @author Nicholas Sikkema
 * @version Revision: 2.0
 * @date Last Updated: 4/21/2015 PM\n Created: 11/12/2014
 * @brief This file is code to control the Timers on the ATMega328P.
 */ 

#include <avr/io.h>
#include <avr/interrupt.h>
#include "Timer.h"

/**
 * @brief Initializes Timer0 with a period of 20ms.
 */ 
inline void Timer0_Initialize ()
{
    /* Set Timer0 initial counter value to 0. */
    TCNT0 = 0x00;
    /* Set timer period of 12.5 ms. */
    OCR0A = 0xC2;
    /* Set the output to be in CTC mode. */
    TCCR0A |= (1<<WGM01);
    /* Set the timer prescaler to 1024. */
    TCCR0B |= (1<<CS02)|(1<<CS00); 
}

/**
 * @brief Enable Timer0 interrupt flag.
 */
void Timer0_Enable()
{
    /* Set the Timer0A Interrupt flag to 1. */
    TIMSK0 |= (1<<OCIE0A);
}

/**
 * @brief Disable Timer0 interrupt flag.
 */
void Timer0_Disable()
{
    /* Set the Timer0A Interrupt flag to 0. */
    TIMSK0 &= ~(1<<OCIE0A);
}

/**
 * @brief Initializes Timer1 as an interrupt at a period of ?.
 */ 
inline void Timer1_Initialize ()
{     
    /* Set Timer0 initial counter value to 0. */
    TCNT1 = 0x00;
    /* Set timer period of 25 ms. */
    OCR1A = 0x0186;
    /* Set the output to be in CTC mode. */
    TCCR1A |= (1<<WGM12);
    /* Set the timer prescaler to 1024. */
    TCCR1B |= (1<<CS12)|(1<<CS10);
}

/**
 * @brief Enable Timer1 interrupt flag.
 */ 
void Timer1_Enable()
{
    /* Set the Timer1A Interrupt flag to 1. */
    TIMSK1 |= (1<<OCIE1A);
}

/**
 * @brief Disable Timer1 interrupt flag.
 */
void Timer1_Disable()
{
    /* Set the Timer1A Interrupt flag to 0. */
    TIMSK1 &= ~(1<<OCIE1A);
}


/**
 * @brief Initializes Timer2 with a period of ?.
 */ 
inline void Timer2_Initialize ()
{
    /* Set Timer0 initial counter value to 0. */
    TCNT2 = 0x00;
    /* Set timer period of 12.5 ms. */
    OCR2A = 0xC2;
    /* Set the output to be in CTC mode. */
    TCCR2A |= (1<<WGM21);
    /* Set the timer prescaler to 1024. */
    TCCR2B |= (1<<CS22)|(1<<CS20);
}

/**
 * @brief Enable Timer2 interrupt flag.
 */ 
void Timer2_Enable()
{
    /* Set the Timer2A interrupt flag to 1. */
    TIMSK2 |= (1<<OCIE2A);
}

/**
 * @brief Disable Timer2 interrupt flag.
 */
void Timer2_Disable()
{
    /* Set the Timer2A interrupt flag to 0. */
    TIMSK2 &= ~(1<<OCIE2A);
}

/**
 * @brief Initializes the timers that are used in the project.
 */ 
void Timer_Initialize(void)
{
    /* Initialize the timers. */
    Timer0_Initialize();
    Timer1_Initialize();
    Timer2_Initialize();
    /* Enable global interrupts. */
    sei();
}