/**
 * @file Battery.c
 * @author Nicholas Sikkema
 * @version Revision: 2.0
 * @date Last Updated: 1/22/2015\n Created: 11/13/2014 2:33:44 PM
 * @brief This file is code to read the battery voltage.
 */ 

/** @brief This is the lowest safe voltage value. */
#define Battery_Safe_Voltage 3.45

#include "../../Microcontroller/ADC/ADC.h"
#include "../../Microcontroller/ADC/CD4051.h"
#include "Battery.h"

/** 
 * @brief This function is used to read the ADC port for the battery.
 * @return ADC value of the battery.
 */
inline int Battery_Read_ADC()
{
    /* Return the ADC value for the battery. */
    return(CD4051_Read_Single_Pin(Battery_Mux_Port));
}

/** 
 * @brief This function is used to read the battery voltage.
 * @return Voltage of the battery.
 */
float Battery_Read_Voltage()
{
    /* Return the voltage value for the battery. */
    return(ADC_Convert_To_Voltage(Battery_Read_ADC()));
}

/** 
 * @brief This function is used to check to see if the battery is below X volts.
 * @return True (1) or False (0)
 */
int Battery_Check_Status()
{
    /* Return if the battery voltage is less than the safe voltage. */
    return(Battery_Read_Voltage()<Battery_Safe_Voltage);
}