/**
 * @file MPX5010GP.c
 * @author Nicholas Sikkema
 * @version Revision: 3.0
 * @date Last Updated: 2/11/2015\n Created: 2/11/2014 11:50 PM
 * @brief This file is code to read the depth from the MPX5010GP pressure sensor.
 */ 

/** @brief The full scale span for the conversion between Voltage and PSI. */
#define VFSS 4.7
/** @brief The offset voltage for the conversion between Voltage and PSI. */
#define V_Offset 0.12
/** @brief Max rated PSI for the pressure sensor. */
#define Max_PSI 1.45

#include "../../Microcontroller/ADC/ADC.h"
#include "../../Microcontroller/ADC/CD4051.h"
#include "MPX5010GP.h"

/**
 * @brief Converts the pressure sensor's ADC value to a depth in PSI.
 * @param ADC_Value The current ADC value for the pressure sensor.
 * @return The current pressure sensor depth in PSI.
 */ 
float MPX5010GP_Calculate_PSI(int ADC_Value)
{
	/* Convert the ADC value to a PSI value. */
    return((ADC_Convert_To_Voltage(ADC_Value)-V_Offset)*Max_PSI/VFSS);
}

/**
 * @brief Read the ADC with the correct multiplexer port selected
 * @return The current pressure sensor ADC value.
 */ 
inline int MPX5010GP_Read_Value()
{
	/* Retrieve the ADC value for the pressure sensor. */
    return(CD4051_Read_Single_Pin(Pressure_Sensor_Mux_Port));
}

/**
 * @brief Obtains the pressure sensor's depth in feet.
 * @return The current pressure sensor depth in feet.
 */ 
float MPX5010GP_Depth()
{
	/* Gather the PSI value and convert the value to a depth value. */
    return(MPX5010GP_Calculate_PSI(MPX5010GP_Read_Value())*Foot_Water_Per_PSI);
}