/**
 * @file Test_Battery.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 6:38:56 PM
 * @brief This file is for the testing of the battery code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdio.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/Power/Battery.h"

/**
 * @brief This function is used to test the reading of the battery code.
 */
void Test_Battery(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    char Buffer_ADC_Value_Voltage[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[80] = {0x00};
    while(1)
    {
        float ADC_Value_Voltage = Battery_Read_Voltage();
        if(Battery_Check_Status() == 0)
        {
            USART_Send_String("Status: Good\r\n");
        }
        else
        {
            USART_Send_String("Status: Bad\r\n");
        }
        sprintf(Buffer,"%s V\r\n", USART_ftoa(ADC_Value_Voltage, Buffer_ADC_Value_Voltage));
        USART_Send_String(Buffer);
        _delay_ms(500);
    }
}