/**
 * @file Test_H_Bridge.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015 \n Created: 2/28/2015 6:35:33 PM
 * @brief This file is for the testing of the I2C H-Bridge code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdint.h>
#include <stdio.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/Communication/I2C_Interface.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/H_Bridge/DRV8830.h"

void Test_H_Bridge_Motor_X_Increase(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=-Motor_Max_Voltage; i<Motor_Max_Voltage; i+=0.07)
        {
            DRV8830_Set_Voltage_Motor_X(i);
            fault = DRV8830_Read_Fault_Motor_X();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_X_Decrease(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=Motor_Max_Voltage; i>-Motor_Max_Voltage; i-=0.07)
        {
            DRV8830_Set_Voltage_Motor_X(i);
            fault = DRV8830_Read_Fault_Motor_X();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_Y_Increase(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=-Motor_Max_Voltage; i<Motor_Max_Voltage; i+=0.07)
        {
            DRV8830_Set_Voltage_Motor_Y(i);
            fault = DRV8830_Read_Fault_Motor_Y();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_Y_Decrease(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=Motor_Max_Voltage; i>-Motor_Max_Voltage; i-=0.07)
        {
            DRV8830_Set_Voltage_Motor_Y(i);
            fault = DRV8830_Read_Fault_Motor_Y();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_Z_Increase(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=-Motor_Max_Voltage; i<Motor_Max_Voltage; i+=0.07)
        {
            DRV8830_Set_Voltage_Motor_Z(i);
            fault = DRV8830_Read_Fault_Motor_Z();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(1500);
        }
    }
}

void Test_H_Bridge_Motor_Z_Decrease(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=Motor_Max_Voltage; i>-Motor_Max_Voltage; i-=0.07)
        {
            DRV8830_Set_Voltage_Motor_Z(i);
            fault = DRV8830_Read_Fault_Motor_Z();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_ALL_Increase(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=-Motor_Max_Voltage; i<=Motor_Max_Voltage; i+=0.07)
        {
            DRV8830_Set_Voltage_Motor_X(i);
            fault = DRV8830_Read_Fault_Motor_X();
            DRV8830_Clear_Fault_Motor_X();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            DRV8830_Set_Voltage_Motor_Y(i);
            DRV8830_Clear_Fault_Motor_Y();
            fault = DRV8830_Read_Fault_Motor_Y();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            DRV8830_Set_Voltage_Motor_Z(i);
            DRV8830_Clear_Fault_Motor_Z();
            fault = DRV8830_Read_Fault_Motor_Z();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

void Test_H_Bridge_Motor_ALL_Decrease(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    DRV8830_Initialize();
    uint8_t fault = 0;
    char Buffer_i[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[50] = {0x00};
    while(1)
    {
        for(float i=Motor_Max_Voltage; i>=-Motor_Max_Voltage; i-=0.07)
        {
            DRV8830_Set_Voltage_Motor_X(i);
            fault = DRV8830_Read_Fault_Motor_X();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            DRV8830_Set_Voltage_Motor_Y(i);
            fault = DRV8830_Read_Fault_Motor_Y();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            DRV8830_Set_Voltage_Motor_Z(i);
            fault = DRV8830_Read_Fault_Motor_Z();
            sprintf(Buffer,"Voltage: %s Fault: %d\r\n", USART_ftoa(i, Buffer_i), fault);
            USART_Send_String(Buffer);
            _delay_ms(500);
        }
    }
}

/**
 * @brief This function is used to test the h-bridge code.
 */ 
void Test_H_Bridge(void)
{
    #if H_Bridge_Test_Mode == 0
        #if H_Bridge_Test_Direction == 0
            Test_H_Bridge_Motor_X_Increase();
        #elif H_Bridge_Test_Direction == 1
            Test_H_Bridge_Motor_X_Decrease();
        #endif
    #elif H_Bridge_Test_Mode == 1
        #if H_Bridge_Test_Direction == 0
            Test_H_Bridge_Motor_Y_Increase();
        #elif H_Bridge_Test_Direction == 1
            Test_H_Bridge_Motor_Y_Decrease();
        #endif
    #elif H_Bridge_Test_Mode == 2
        #if H_Bridge_Test_Direction == 0
            Test_H_Bridge_Motor_Z_Increase();
        #elif H_Bridge_Test_Direction == 1
            Test_H_Bridge_Motor_Z_Decrease();
        #endif
    #elif H_Bridge_Test_Mode == 3
        #if H_Bridge_Test_Direction == 0
            Test_H_Bridge_Motor_ALL_Increase();
        #elif H_Bridge_Test_Direction == 1
            Test_H_Bridge_Motor_ALL_Decrease();
        #endif
    #endif
}