/**
 * @file Test_I2C_Compass.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 6:35:33 PM
 * @brief This file is for the testing of the I2C Compass code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdint.h>
#include <stdio.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/Communication/I2C_Interface.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/IMU/LSM303.h"

void Test_I2C_Compass_Mag_Acc(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    LSM303_Initialize();
    int16_t Acc[3] = {0, 0, 0};
    int16_t Mag[3] = {0, 0, 0};
    char Buffer[50] = {0x00};
    while(1)
    {
        LSM303_Read_Mag(Mag);
        LSM303_Read_Acc(Acc);
        sprintf(Buffer,"Acc: %d, %d, %d Mag: %d, %d, %d\r\n", Mag[0], Mag[1], Mag[2], Acc[0], Acc[1], Acc[2]);
        USART_Send_String(Buffer);
        _delay_ms(100);
    }
}

void Test_I2C_Compass_Heading(void)
{
    I2C_Interface_Initialize();
    USART_Initialize();
    LSM303_Initialize();
    int16_t Acc[3] = {0, 0, 0};
    int16_t Mag[3] = {0, 0, 0};
    char Buffer_Heading[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    float Heading = 0;
    char Buffer[10] = {0x00};
    while(1)
    {
        LSM303_Read_Mag(Mag);
        LSM303_Read_Acc(Acc);
        Heading = LSM303_Heading(Acc, Mag);
        sprintf(Buffer,"%s\r\n", USART_ftoa(Heading, Buffer_Heading));
        USART_Send_String(Buffer);
        _delay_ms(100);
    }    
}

/**
 * @brief This function is used to test the compass code.
 */ 
void Test_I2C_Compass(void)
{
    #if Compass_Test_Mode == 0
        Test_I2C_Compass_Mag_Acc();
    #elif Compass_Test_Mode == 1
        Test_I2C_Compass_Heading();
    #endif
}