/**
 * @file Test_Motor_Control.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 6:31:21 PM
 * @brief This file is for the testing of the motor control code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif
/**
 * @brief Update speeds for the motor control test function.\n
 * The rate is equal to (50 ms)*(variable value).
 * @warning This is value needs to be an integer.
 */ 
#define Motor_Control_Test_Speed 1000

#include <util/delay.h>
#include <stdio.h>
#include "../Algorithms/Motor_Control/Motor_Control.h"
#include "../Master_Build_Control.h"
#include "../Microcontroller/Communication/I2C_Interface.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Subsystem/H_Bridge/DRV8830.h"
#include "../Subsystem/IMU/LSM303.h"

void Test_Motor_Control_X_Varying(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_X_Flag_Update(1);
    char Buffer[50] = {0x00};
    while(1)
    {
        int Motor_Value = -5;
        for(int i=0; Motor_Value<=5; i++)
        {
            Motor_Control_Update_Velocity_X(Motor_Value);
            if(i%Motor_Control_Test_Speed==1)
            {
                Motor_Value++;
            }
            Motor_Control();
            sprintf(Buffer,"i: %d, Motor Value: %d\r\n", i, Motor_Value);
            USART_Send_String(Buffer);
            Motor_Control_Enable_Flag();
            _delay_ms(50);
        }
    }
}

void Test_Motor_Control_Y_Varying(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_Y_Flag_Update(1);
    char Buffer[50] = {0x00};
    while(1)
    {
        int Motor_Value = -5;
        for(int i=0; Motor_Value<=5; i++)
        {
            Motor_Control_Update_Velocity_Y(Motor_Value);
            if(i%Motor_Control_Test_Speed==1)
            {
                Motor_Value++;
            }
            Motor_Control();
            sprintf(Buffer,"i: %d, Motor Value: %d\r\n", i, Motor_Value);
            USART_Send_String(Buffer);
            Motor_Control_Enable_Flag();
            _delay_ms(50);
        }
    }
}

void Test_Motor_Control_Z_Varying(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_Z_Flag_Update(1);
    char Buffer[50] = {0x00};
    while(1)
    {
        int Motor_Value = 0;
        for(int i=0; Motor_Value<2.5; i++)
        {
            Motor_Control_Update_Depth_Z(Motor_Value);
            if(i%Motor_Control_Test_Speed==1)
            {
                Motor_Value++;
            }
            Motor_Control();
            sprintf(Buffer,"i: %d, Motor Value: %d\r\n", i, Motor_Value);
            USART_Send_String(Buffer);
            Motor_Control_Enable_Flag();
            _delay_ms(50);
        }
    }
}

void Test_Motor_Control_X_Constant(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_X_Flag_Update(1);
    char Buffer[50] = {0x00};
    int Motor_Value = 0;
    while(1)
    {
        Motor_Control_Update_Velocity_X(Motor_Value);
        Motor_Control();
        sprintf(Buffer,"Motor Value: %d\r\n", Motor_Value);
        USART_Send_String(Buffer);
        Motor_Control_Enable_Flag();
        _delay_ms(50);
    }
}

void Test_Motor_Control_Y_Constant(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_Y_Flag_Update(1);
    char Buffer[50] = {0x00};
    int Motor_Value = 0;
    while(1)
    {
        Motor_Control_Update_Velocity_Y(Motor_Value);
        Motor_Control();
        sprintf(Buffer,"Motor Value: %d\r\n", Motor_Value);
        USART_Send_String(Buffer);
        Motor_Control_Enable_Flag();
        _delay_ms(50);
    }
}

void Test_Motor_Control_Z_Constant(void)
{
    I2C_Interface_Initialize();
    DRV8830_Initialize();
    USART_Initialize();
    CD4051_Initialize();
    Motor_Control_Motor_Z_Flag_Update(1);
    char Buffer[50] = {0x00};
    int Motor_Value = 1;
    while(1)
    {
        Motor_Control_Update_Depth_Z(Motor_Value);
        Motor_Control();
        sprintf(Buffer,"Motor Value: %d\r\n", Motor_Value);
        USART_Send_String(Buffer);
        Motor_Control_Enable_Flag();
        _delay_ms(50);
    }
}

/**
 * @brief This function is used to test the motor control loops for the three motors.
 */
void Test_Motor_Control(void)
{
    #if Motor_Control_Test_Mode == 0
        Test_Motor_Control_X_Varying();
    #elif Motor_Control_Test_Mode == 1
        Test_Motor_Control_Y_Varying();
    #elif Motor_Control_Test_Mode == 2
        Test_Motor_Control_Z_Varying();
    #elif Motor_Control_Test_Mode == 3
        Test_Motor_Control_X_Constant();
    #elif Motor_Control_Test_Mode == 4
        Test_Motor_Control_Y_Constant();
    #elif Motor_Control_Test_Mode == 5
        Test_Motor_Control_Z_Constant();
    #endif
}