/**
 * @file Test_Multiplexer.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 7:29:55 PM
 * @brief This file is for the testing of the multiplexer code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdio.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/ADC/ADC.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Microcontroller/Communication/USART.h"

void Test_Multiplexer_Single_Pin(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    int ADC_Value_Pin = 0;
    char Buffer[20] = {0x00};
    while(1)
    {
		/* Read the ADC value. */
        ADC_Value_Pin = CD4051_Read_Single_Pin(0x0);
		/* Print the ADC value. */
        sprintf(Buffer,"%d\r\n", ADC_Value_Pin);
        USART_Send_String(Buffer);
		/* Delay between the last check. */
        _delay_ms(50);
    }
}

void Test_Multiplexer_Multiple_Pins(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    int ADC_Values[] = {0,0,0,0,0,0,0,0};
    char Buffer[100] = {0x00};
    while(1)
    {
		/* Read the range of ADC values. */
        CD4051_Read_Range(ADC_Values, 0x0, 0x7);
		/* Print the range of ADC values. */
        sprintf(Buffer,"%d, %d, %d, %d, %d, %d, %d, %d\r\n", ADC_Values[0], ADC_Values[1], ADC_Values[2], ADC_Values[3], ADC_Values[4], ADC_Values[5], ADC_Values[6], ADC_Values[7]);
        USART_Send_String(Buffer);
		/* Delay between the last check. */
        _delay_ms(50);
    }
}

void Test_Multiplexer_Voltage_Conversion()
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    int ADC_Value = 0;
    float Voltage_Value = 0;
    char Buffer_Voltage_Value[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[20] = {0x00};
    while(1)
    {
		/* Read the ADC value. */
        ADC_Value = CD4051_Read_Single_Pin(0x0);
		/* Convert the ADC value to a voltage. */
        Voltage_Value = ADC_Convert_To_Voltage(ADC_Value);
		/* Print the ADC and voltage value. */
        sprintf(Buffer,"%d, %s V\r\n", ADC_Value, USART_ftoa(Voltage_Value, Buffer_Voltage_Value));
        USART_Send_String(Buffer);
		/* Delay between the last check. */
        _delay_ms(50);
    }
}

void Test_Multiplexer_Voltage_Multiple_Conversions()
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    int ADC_Value = 0;
    float Voltage_Value = 0;
    char Buffer_Voltage_Value[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[20] = {0x00};
    while(1)
    {
		/* Loop through the indexes for the multiplexer. */
        for(int i = 0; i < 7; i++)
        {
            /* Read the ADC value. */
            ADC_Value = CD4051_Read_Single_Pin(i);
            /* Convert the ADC value to a voltage. */
            Voltage_Value = ADC_Convert_To_Voltage(ADC_Value);
            /* Print the ADC and voltage value. */
            sprintf(Buffer,"%d, %s V\r\n", ADC_Value, USART_ftoa(Voltage_Value, Buffer_Voltage_Value));
            USART_Send_String(Buffer);
        }
		/* Delay between the last check. */
        _delay_ms(50);
    }
}

/**
 * @brief This function is used to test the multiplexer ADC code.
 */ 
void Test_Multiplexer(void)
{
    #if Multiplexer_Test_Mode == 0
        Test_Multiplexer_Single_Pin();
    #elif Multiplexer_Test_Mode == 1
        Test_Multiplexer_Multiple_Pins();
    #elif Multiplexer_Test_Mode == 2
        Test_Multiplexer_Voltage_Conversion();
    #elif Multiplexer_Test_Mode == 3
        Test_Multiplexer_Voltage_Multiple_Conversions();
    #endif
}