/**
 * @file Test_Photodiodes.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 7:28:51 PM
 * @brief This file is for the testing of the photodiode code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdio.h>
#include <stdlib.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/Light/CLS15.h"
#include "../Subsystem/Light/XPEBBL.h"

void Test_Photodiodes_Print_Front(void)
{
	/* Initialize the temporary variables. */
    char Buffer[50] = {0x00};
	/* Retrieve the current photodiode ADC value. */
    uint16_t Photodiode_ADC = CLS15_Retrieve_Photodiode_ADC_Rear();
	/* Print the ADC information. */
    sprintf(Buffer,"Front: %u\r\n", Photodiode_ADC);
    USART_Send_String(Buffer);
}

void Test_Photodiodes_Print_Left(void)
{
	/* Initialize the temporary variables. */
    char Buffer[100] = {0x00};
    char Buffer_Photodiode_Ratio[FLOATING_POINT_BUFFER_SIZE] = {0x00};
	/* Retrieve the current photodiode ADC values and ratio. */
	uint16_t Photodiode_ADC_Front = CLS15_Retrieve_Photodiode_ADC_Left_Front();
    uint16_t Photodiode_ADC_Rear = CLS15_Retrieve_Photodiode_ADC_Left_Rear();
    float Photodiode_Ratio = CLS15_Retrieve_Photodiode_Ratio_Left();
    /* Print the ADC information. */
    sprintf(Buffer,"Left Front: %u Rear: %u Ratio: %s\r\n", Photodiode_ADC_Front, Photodiode_ADC_Rear, USART_ftoa(Photodiode_Ratio, Buffer_Photodiode_Ratio));
    USART_Send_String(Buffer);
}

void Test_Photodiodes_Print_Right(void)
{
	/* Initialize the temporary variables. */
    char Buffer[100] = {0x00};
	char Buffer_Photodiode_Ratio[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    /* Retrieve the current photodiode ADC values and ratio. */
	uint16_t Photodiode_ADC_Front = CLS15_Retrieve_Photodiode_ADC_Right_Front();
    uint16_t Photodiode_ADC_Rear = CLS15_Retrieve_Photodiode_ADC_Right_Rear();
    float Photodiode_Ratio = CLS15_Retrieve_Photodiode_Ratio_Right();
    /* Print the ADC information. */
    sprintf(Buffer,"Right Front: %u Rear: %u Ratio: %s\r\n", Photodiode_ADC_Front, Photodiode_ADC_Rear, USART_ftoa(Photodiode_Ratio, Buffer_Photodiode_Ratio));
    USART_Send_String(Buffer);
}

void Test_Photodiodes_Print_Rear(void)
{
    /* Initialize the temporary variables. */
    char Buffer[50] = {0x00};
    /* Retrieve the current photodiode ADC value. */
    int Photodiode_ADC = CLS15_Retrieve_Photodiode_ADC_Rear();
	/* Print the ADC information. */
    sprintf(Buffer,"Rear: %d\r\n", Photodiode_ADC);
    USART_Send_String(Buffer);
}

void Test_Photodiodes_Front(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    while(1)
    {
		/* Update all of the photodiodes. */
        CLS15_Update_Photodiode_Values(8);
        /* Print the current value for the front photodiode. */
        Test_Photodiodes_Print_Front();
        /* Add a line between all of the reads. */
        USART_Send_String("\n");
        /* Delay between the last check. */
        _delay_ms(100);
    }
}

void Test_Photodiodes_Left(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    while(1)
    {
		/* Update all of the photodiodes. */
        CLS15_Update_Photodiode_Values(8);
        /* Print the current value for the left photodiode. */
        Test_Photodiodes_Print_Left();
        /* Add a line between all of the reads. */
        USART_Send_String("\n");
        /* Delay between the last check. */
        _delay_ms(100);
    }
}

void Test_Photodiodes_Right(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    while(1)
    {
		/* Update all of the photodiodes. */
        CLS15_Update_Photodiode_Values(8);
        /* Print the current value for the right photodiode. */
        Test_Photodiodes_Print_Right();
        /* Add a line between all of the reads. */
        USART_Send_String("\n");
        /* Delay between the last check. */
        _delay_ms(100);
    }
}

void Test_Photodiodes_Rear(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    while(1)
    {
		/* Update all of the photodiodes. */
        CLS15_Update_Photodiode_Values(8);
        /* Print the current value for the rear photodiode. */
        Test_Photodiodes_Print_Rear();
        /* Add a line between all of the reads. */
        USART_Send_String("\n");
        /* Delay between the last check. */
        _delay_ms(100);
    }
}

void Test_Photodiodes_All(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    while(1)
    {
		/* Update all of the photodiodes. */
        CLS15_Update_Photodiode_Values(8);
        /* Print the current value for the front photodiode. */
        Test_Photodiodes_Print_Front();
        /* Print the current value for the left photodiode. */
        Test_Photodiodes_Print_Left();
        /* Print the current value for the right photodiode. */
        Test_Photodiodes_Print_Right();
        /* Print the current value for the rear photodiode. */
        Test_Photodiodes_Print_Rear();
        /* Add a line between all of the reads. */
        USART_Send_String("\n");
        /* Delay between the last check. */
        _delay_ms(100);
    }
}

void Test_Photodiodes_All_With_LED(void)
{
	/* Initialize the multiplexer. */
	CD4051_Initialize();
	/* Initialize USART communication. */
	USART_Initialize();
	/* Initialize the LEDs. */
    XPEBBL_Initialize();
    while(1)
    {
		/* Change the current LED and all of the photodiodes that are not by the current LED. */
        CLS15_Update_Photodiode_Values(XPEBLL_Change_LED());
		/* Print the current value for the front photodiode. */
        Test_Photodiodes_Print_Front();
		/* Print the current value for the left photodiode. */
        Test_Photodiodes_Print_Left();
		/* Print the current value for the right photodiode. */
        Test_Photodiodes_Print_Right();
		/* Print the current value for the rear photodiode. */
        Test_Photodiodes_Print_Rear();
		/* Add a line between all of the reads. */
        USART_Send_String("\n");
		/* Delay between the last check. */
        _delay_ms(200);
    }
}

/**
 * @brief This function is used to test the reading of the photodiodes code.
 */
void Test_Photodiodes(void)
{
	/* Test the front photodiode. */
    #if Photodiode_Test_Mode == 0
        Test_Photodiodes_Front();
	/* Test the left photodiodes. */
    #elif Photodiode_Test_Mode == 1
        Test_Photodiodes_Left();
	/* Test the right photodiode. */
    #elif Photodiode_Test_Mode == 2
        Test_Photodiodes_Right();
	/* Test the rear photodiode. */
    #elif Photodiode_Test_Mode == 3
        Test_Photodiodes_Rear();
	/* Test the all photodiodes. */
    #elif Photodiode_Test_Mode == 4
        Test_Photodiodes_All();
	/* Test the all photodiodes with LEDs. */
    #elif Photodiode_Test_Mode == 5
        Test_Photodiodes_All_With_LED();
    #endif
}