/**
 * @file Test_Pressure_Sensor.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 6:41:16 PM
 * @brief This file is for the testing of the pressure sensor code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdio.h>
#include "../Master_Build_Control.h"
#include "../Microcontroller/ADC/ADC.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/Pressure/MPX5010GP.h"

/**
 * @brief This function is used to test the reading of the pressure sensor.
 */
void Test_Pressure_Sensor(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    int ADC_Value = 0;
    float ADC_Value_Voltage = 0;
    char Buffer_ADC_Value_Voltage[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    float PSI_Value = 0;
    char Buffer_PSI_Value[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    float Temp_Depth = 0;
    char Buffer_Temp_Depth[FLOATING_POINT_BUFFER_SIZE] = {0x00};
    char Buffer[80] = {0x00};
    while(1)
    {
        /* Read the adc pin value. */
        ADC_Value = CD4051_Read_Single_Pin(Pressure_Sensor_Mux_Port);
        /* Convert the adc value to a voltage. */
        ADC_Value_Voltage = ADC_Convert_To_Voltage(ADC_Value);
        /* Convert the voltage value to PSI. */
        PSI_Value = MPX5010GP_Calculate_PSI(ADC_Value);
        /* Convert the PSI to a depth. */
        Temp_Depth = PSI_Value*Foot_Water_Per_PSI;
        /* Print the pressure sensor information. */
        sprintf(Buffer,"%d, %s V, %s PSI, %s ft\r\n", ADC_Value, USART_ftoa(ADC_Value_Voltage, Buffer_ADC_Value_Voltage), USART_ftoa(PSI_Value, Buffer_PSI_Value), USART_ftoa(Temp_Depth, Buffer_Temp_Depth));
        USART_Send_String(Buffer);
        /* Delay between the last check. */
        _delay_ms(50);
    }
}