/**
 * @file Test_Swarming.c
 * @author Nicholas Sikkema
 * @version Revision: 1.0
 * @date Last Updated: 4/29/2015\n Created: 2/28/2015 5:59:02 PM
 * @brief This file is for the testing of the swarming code.
 */

#ifndef F_CPU
    /** @brief The current clock speed for the microcontroller. */
    #define F_CPU 16000000UL
#endif

#include <util/delay.h>
#include <stdio.h>
#include "../Algorithms/Navigation/Swarming.h"
#include "../Master_Build_Control.h"
#include "../Microcontroller/ADC/CD4051.h"
#include "../Microcontroller/Communication/USART.h"
#include "../Subsystem/Light/CLS15.h"

/**
 * @brief This function is used to test the swarming code.
 */ 
int Test_Swarming(void)
{
    /* Initialize the multiplexer. */
    CD4051_Initialize();
    /* Initialize USART communication. */
    USART_Initialize();
    /* Initialize the temporary variables. */
    char Buffer[50] = {0x00};
    while(1)
    {
        /* Update the photodiode values. */
        CLS15_Update_Photodiode_Values(8);
        /* Update the X and Y for the swarm algorithm. */
        Swarming();
        /* Obtain the X and Y from the swarm algorithm. */
        int X = Swarming_Retrieve_X_Offset();
        int Y = Swarming_Retrieve_Y_Offset();
        /* Print the swarm information. */
        sprintf(Buffer,"X: %d, Y: %d\r\n", X, Y);
        USART_Send_String(Buffer);
        /* Delay between the last check. */
        _delay_ms(100);
    }
}